EXPORTS
	??1CDiskNotifyHandler@@UAE@XZ @ 1 NONAME ; CDiskNotifyHandler::~CDiskNotifyHandler(void)
	?AllowDismount@CDiskNotifyHandler@@QAEHH@Z @ 2 NONAME ; int CDiskNotifyHandler::AllowDismount(int)
	?CancelNotifyDisk@CDiskNotifyHandler@@QAEXXZ @ 3 NONAME ; void CDiskNotifyHandler::CancelNotifyDisk(void)
	?CancelNotifyDiskSpace@CDiskNotifyHandler@@QAEXAB_JH@Z @ 4 NONAME ; void CDiskNotifyHandler::CancelNotifyDiskSpace(long long const &, int)
	?CancelNotifyDiskSpace@CDiskNotifyHandler@@QAEXH@Z @ 5 NONAME ; void CDiskNotifyHandler::CancelNotifyDiskSpace(int)
	?CancelNotifyDiskSpace@CDiskNotifyHandler@@QAEXXZ @ 6 NONAME ; void CDiskNotifyHandler::CancelNotifyDiskSpace(void)
	?CancelNotifyDismount@CDiskNotifyHandler@@QAEXH@Z @ 7 NONAME ; void CDiskNotifyHandler::CancelNotifyDismount(int)
	?CancelNotifyDismount@CDiskNotifyHandler@@QAEXXZ @ 8 NONAME ; void CDiskNotifyHandler::CancelNotifyDismount(void)
	?CancelNotifyEntry@CDiskNotifyHandler@@QAEXABVTDesC16@@@Z @ 9 NONAME ; void CDiskNotifyHandler::CancelNotifyEntry(class TDesC16 const &)
	?CancelNotifyEntry@CDiskNotifyHandler@@QAEXW4TNotifyType@@ABVTDesC16@@@Z @ 10 NONAME ; void CDiskNotifyHandler::CancelNotifyEntry(enum TNotifyType, class TDesC16 const &)
	?CancelNotifyEntry@CDiskNotifyHandler@@QAEXXZ @ 11 NONAME ; void CDiskNotifyHandler::CancelNotifyEntry(void)
	?HandleNotifyDisk@MDiskNotifyHandlerCallback@@UAEXHABVTDiskEvent@1@@Z @ 12 NONAME ; void MDiskNotifyHandlerCallback::HandleNotifyDisk(int, class MDiskNotifyHandlerCallback::TDiskEvent const &)
	?HandleNotifyDiskSpace@MDiskNotifyHandlerCallback@@UAEXHABVTDiskSpaceEvent@1@@Z @ 13 NONAME ; void MDiskNotifyHandlerCallback::HandleNotifyDiskSpace(int, class MDiskNotifyHandlerCallback::TDiskSpaceEvent const &)
	?HandleNotifyDismount@MDiskNotifyHandlerCallback@@UAEXHABVTDismountEvent@1@@Z @ 14 NONAME ; void MDiskNotifyHandlerCallback::HandleNotifyDismount(int, class MDiskNotifyHandlerCallback::TDismountEvent const &)
	?HandleNotifyEntry@MDiskNotifyHandlerCallback@@UAEXHABVTEntryEvent@1@@Z @ 15 NONAME ; void MDiskNotifyHandlerCallback::HandleNotifyEntry(int, class MDiskNotifyHandlerCallback::TEntryEvent const &)
	?NewL@CDiskNotifyHandler@@SAPAV1@AAVMDiskNotifyHandlerCallback@@AAVRFs@@@Z @ 16 NONAME ; class CDiskNotifyHandler * CDiskNotifyHandler::NewL(class MDiskNotifyHandlerCallback &, class RFs &)
	?NotifyDisk@CDiskNotifyHandler@@QAEHXZ @ 17 NONAME ; int CDiskNotifyHandler::NotifyDisk(void)
	?NotifyDiskSpace@CDiskNotifyHandler@@QAEHAB_JH@Z @ 18 NONAME ; int CDiskNotifyHandler::NotifyDiskSpace(long long const &, int)
	?NotifyDismount@CDiskNotifyHandler@@QAEHH@Z @ 19 NONAME ; int CDiskNotifyHandler::NotifyDismount(int)
	?NotifyEntry@CDiskNotifyHandler@@QAEHW4TNotifyType@@ABVTDesC16@@@Z @ 20 NONAME ; int CDiskNotifyHandler::NotifyEntry(enum TNotifyType, class TDesC16 const &)
	?StartDismount@CDiskNotifyHandler@@QAEHHVTTimeIntervalMicroSeconds32@@@Z @ 21 NONAME ; int CDiskNotifyHandler::StartDismount(int, class TTimeIntervalMicroSeconds32)
	?HandleNotifyDismountFinished@MDiskNotifyHandlerCallback@@UAEXHABVTDismountFinishedEvent@1@@Z @ 22 NONAME ; void MDiskNotifyHandlerCallback::HandleNotifyDismountFinished(int, class MDiskNotifyHandlerCallback::TDismountFinishedEvent const &)
	?CancelStartedDismount@CDiskNotifyHandler@@QAEXXZ @ 23 NONAME ; void CDiskNotifyHandler::CancelStartedDismount(void)
	?CancelStartedDismount@CDiskNotifyHandler@@QAEXH@Z @ 24 NONAME ; void CDiskNotifyHandler::CancelStartedDismount(int)

